@@ -32,9 +32,7 @@ del get_versions
 
 
 def start_logger():
-    FORMAT_LOG = (
-        "%(levelname)-8s %(asctime)s %(module)s.%(funcName)s :\n\t\t\t\t\t%(message)s"
-    )
+    FORMAT_LOG = "%(levelname)-8s %(asctime)s %(module)s.%(funcName)s :\n\t%(message)s"
     logger = logging.getLogger("pet")
     if len(logger.handlers) == 0:
         # set up logging to CONSOLE
@@ -409,20 +407,14 @@ VAR_DESCR = dict(
         nc_name="previous_cost",
         nc_type="float32",
         nc_dims=("obs",),
-        nc_attr=dict(
-            long_name="Previous cost for previous observation",
-            comment="",
-        ),
+        nc_attr=dict(long_name="Previous cost for previous observation", comment="",),
     ),
     next_cost=dict(
         attr_name=None,
         nc_name="next_cost",
         nc_type="float32",
         nc_dims=("obs",),
-        nc_attr=dict(
-            long_name="Next cost for next observation",
-            comment="",
-        ),
+        nc_attr=dict(long_name="Next cost for next observation", comment="",),
     ),
     n=dict(
         attr_name=None,
@@ -633,8 +625,7 @@ VAR_DESCR = dict(
         nc_type="f4",
         nc_dims=("obs",),
         nc_attr=dict(
-            long_name="Log base 10 background chlorophyll",
-            units="Log(Chl/[mg/m^3])",
+            long_name="Log base 10 background chlorophyll", units="Log(Chl/[mg/m^3])",
         ),
     ),
     year=dict(
