@@ -3,6 +3,7 @@
 Class to create network of observations
 """
 import logging
+import time
 from glob import glob
 
 from numba import njit
@@ -15,15 +16,17 @@ from numpy import (
     empty,
     in1d,
     ones,
+    uint16,
     uint32,
     unique,
     where,
     zeros,
 )
 
+from ..dataset.grid import GridCollection
 from ..generic import build_index, wrap_longitude
 from ..poly import bbox_intersection, vertice_overlap
-from .groups import GroupEddiesObservations, get_missing_indices
+from .groups import GroupEddiesObservations, get_missing_indices, particle_candidate
 from .observation import EddiesObservations
 from .tracking import TrackEddiesObservations, track_loess_filter, track_median_filter
 
@@ -77,10 +80,10 @@ class Buffer(metaclass=Singleton):
 
 @njit(cache=True)
 def fix_next_previous_obs(next_obs, previous_obs, flag_virtual):
-    """when an observation is virtual, we have to fix the previous and next obs
+    """When an observation is virtual, we have to fix the previous and next obs
 
-    :param np.array(int)  next_obs    : indice of next observation from network
-    :param np.array(int   previous_obs: indice of previous observation from network
+    :param np.array(int)  next_obs    : index of next observation from network
+    :param np.array(int   previous_obs: index of previous observation from network
     :param np.array(bool) flag_virtual: if observation is virtual or not
     """
 
@@ -88,8 +91,8 @@ def fix_next_previous_obs(next_obs, previous_obs, flag_virtual):
         if not flag_virtual[i_o]:
             continue
 
-        # if there is many virtual side by side, there is some values writted multiple times.
-        #   but it should not be slow
+        # if there are several consecutive virtuals, some values are written multiple times.
+        # but it should not be slow
         next_obs[i_o - 1] = i_o
         next_obs[i_o] = i_o + 1
         previous_obs[i_o] = i_o - 1
@@ -108,13 +111,12 @@ class NetworkObservations(GroupEddiesObservations):
 
     def find_segments_relative(self, obs, stopped=None, order=1):
         """
-        find all relative segments within an event from an order.
+        Find all relative segments from obs linked with merging/splitting events at a specific order.
 
-        :param int obs: indice of event after the event
-        :param int stopped: indice of event before the event
+        :param int obs: index of observation after the event
+        :param int stopped: index of observation before the event
         :param int order: order of relatives accepted
-
-        :return: all segments relatives
+        :return: all relative segments
         :rtype: EddiesObservations
         """
 
@@ -133,9 +135,9 @@ class NetworkObservations(GroupEddiesObservations):
             return nw.relatives([i_obs, i_stopped], order=order)
 
     def get_missing_indices(self, dt):
-        """find indices where observations is missing.
+        """Find indices where observations are missing.
 
-        As network have all untrack observation in tracknumber `self.NOGROUP`,
+        As network have all untracked observation in tracknumber `self.NOGROUP`,
             we don't compute them
 
         :param int,float dt: theorical delta time between 2 observations
@@ -195,8 +197,8 @@ class NetworkObservations(GroupEddiesObservations):
         """
         Select network on time duration
 
-        :param int nb_day_min: Minimal number of day covered by one network, if negative -> not used
-        :param int nb_day_max: Maximal number of day covered by one network, if negative -> not used
+        :param int nb_day_min: Minimal number of days covered by one network, if negative -> not used
+        :param int nb_day_max: Maximal number of days covered by one network, if negative -> not used
         """
         if nb_day_max < 0:
             nb_day_max = 1000000000000
@@ -213,11 +215,11 @@ class NetworkObservations(GroupEddiesObservations):
     @classmethod
     def from_split_network(cls, group_dataset, indexs, **kwargs):
         """
-        Build a NetworkObservations object with Group dataset and indexes
+        Build a NetworkObservations object with Group dataset and indices
 
         :param TrackEddiesObservations group_dataset: Group dataset
         :param indexs: result from split_network
-        return NetworkObservations
+        :return: NetworkObservations
         """
         index_order = indexs.argsort(order=("group", "track", "time"))
         network = cls.new_like(group_dataset, len(group_dataset), **kwargs)
@@ -227,7 +229,7 @@ class NetworkObservations(GroupEddiesObservations):
                 continue
             network[field][:] = group_dataset[field][index_order]
         network.segment[:] = indexs["track"][index_order]
-        # n & p must be re-index
+        # n & p must be re-indexed
         n, p = indexs["next_obs"][index_order], indexs["previous_obs"][index_order]
         # we add 2 for -1 index return index -1
         translate = -ones(index_order.max() + 2, dtype="i4")
@@ -243,14 +245,14 @@ class NetworkObservations(GroupEddiesObservations):
 
     def correct_close_events(self, nb_days_max=20):
         """
-        transform event where
-        segment A split to B, then A merge into B
+        Transform event where
+        segment A splits from segment B, then x days after segment B merges with A
 
         to
 
-        segment A split to B, then B merge to A
+        segment A splits from segment B then x days after segment A merges with B (B will be longer)
 
-        these events are filtered with `nb_days_max`, which the event have to take place in less than `nb_days_max`
+        These events have to last less than `nb_days_max` to be changed.
 
         :param float nb_days_max: maximum time to search for splitting-merging event
         """
@@ -265,7 +267,7 @@ class NetworkObservations(GroupEddiesObservations):
 
         previous_obs, next_obs = self.previous_obs, self.next_obs
 
-        # record for every segments, the slice, indice of next obs & indice of previous obs
+        # record for every segment the slice, index of next obs & index of previous obs
         for i, seg, _ in self.iter_on(segment):
             if i.start == i.stop:
                 continue
@@ -284,12 +286,12 @@ class NetworkObservations(GroupEddiesObservations):
 
             n_seg = segment[i_seg_n]
 
-            # if segment has splitting
+            # if segment is split
             if i_seg_n != -1:
                 seg2_slice, i2_seg_p, i2_seg_n = segments_connexion[n_seg]
                 p2_seg = segment[i2_seg_p]
 
-                # if it merge on the first in a certain time
+                # if it merges on the first in a certain time
                 if (p2_seg == seg_corrected) and (
                     _time[i_seg_n] - _time[i2_seg_p] < nb_days_max
                 ):
@@ -309,11 +311,10 @@ class NetworkObservations(GroupEddiesObservations):
 
     def sort(self, order=("track", "segment", "time")):
         """
-        sort observations
+        Sort observations
 
-        :param tuple order: order or sorting. Passed to `np.argsort`
+        :param tuple order: order or sorting. Given to :func:`numpy.argsort`
         """
-
         index_order = self.obs.argsort(order=order)
         for field in self.elements:
             self[field][:] = self[field][index_order]
@@ -329,13 +330,13 @@ class NetworkObservations(GroupEddiesObservations):
 
     def find_link(self, i_observations, forward=True, backward=False):
         """
-        find all observations where obs `i_observation` could be
+        Find all observations where obs `i_observation` could be
         in future or past.
 
-        if forward=True, search all observation  where water
+        If forward=True, search all observations where water
         from obs "i_observation" could go
 
-        if backward=True, search all observation
+        If backward=True, search all observation
         where water from obs `i_observation` could come from
 
         :param int,iterable(int) i_observation:
@@ -425,7 +426,7 @@ class NetworkObservations(GroupEddiesObservations):
 
     def connexions(self, multi_network=False):
         """
-        create dictionnary for each segments, gives the segments which interact with
+        Create dictionnary for each segment, gives the segments in interaction with
         """
         if multi_network:
             segment = self.segment_track_array
@@ -444,7 +445,7 @@ class NetworkObservations(GroupEddiesObservations):
             if i.start == i.stop:
                 continue
             i_p, i_n = previous_obs[i.start], next_obs[i.stop - 1]
-            # segment of interaction
+            # segment in interaction
             p_seg, n_seg = segment[i_p], segment[i_n]
             # Where segment are called
             if i_p != -1:
@@ -485,39 +486,71 @@ class NetworkObservations(GroupEddiesObservations):
             d[i0:i1] = v
         return d
 
-    def relative(self, i_obs, order=2, direct=True, only_past=False, only_future=False):
-        """
-        Extract the segments at a certain order from one observation.
-
-        :param list obs: indice of observation for relative computation
-        :param int order: order of relatives wanted. 0 means only observations in obs, 1 means direct relatives, ...
-
-        :return: all segments relatives
-        :rtype: EddiesObservations
-        """
-
-        d = self.segment_relative_order(self.segment[i_obs])
-        m = (d <= order) * (d != -1)
-        return self.extract_with_mask(m)
-
-    def relatives(self, obs, order=2, direct=True, only_past=False, only_future=False):
+    def relatives(self, obs, order=2):
         """
         Extract the segments at a certain order from multiple observations.
 
-        :param list obs: indices of observation for relatives computation
+        :param iterable,int obs:
+            indices of observation for relatives computation. Can be one observation (int)
+            or collection of observations (iterable(int))
         :param int order: order of relatives wanted. 0 means only observations in obs, 1 means direct relatives, ...
-
-        :return: all segments relatives
+        :return: all segments' relatives
         :rtype: EddiesObservations
         """
+        segment = self.segment_track_array
+        previous_obs, next_obs = self.previous_obs, self.next_obs
 
-        mask = zeros(self.segment.shape, dtype=bool)
+        segments_connexion = dict()
 
-        for i_obs in obs:
-            d = self.segment_relative_order(self.segment[i_obs])
-            mask += (d <= order) * (d != -1)
+        for i_slice, seg, _ in self.iter_on(segment):
+            if i_slice.start == i_slice.stop:
+                continue
 
-        return self.extract_with_mask(mask)
+            i_p, i_n = previous_obs[i_slice.start], next_obs[i_slice.stop - 1]
+            p_seg, n_seg = segment[i_p], segment[i_n]
+
+            # dumping slice into dict
+            if seg not in segments_connexion:
+                segments_connexion[seg] = [i_slice, []]
+            else:
+                segments_connexion[seg][0] = i_slice
+
+            if i_p != -1:
+
+                if p_seg not in segments_connexion:
+                    segments_connexion[p_seg] = [None, []]
+
+                # backward
+                segments_connexion[seg][1].append(p_seg)
+                segments_connexion[p_seg][1].append(seg)
+
+            if i_n != -1:
+                if n_seg not in segments_connexion:
+                    segments_connexion[n_seg] = [None, []]
+
+                # forward
+                segments_connexion[seg][1].append(n_seg)
+                segments_connexion[n_seg][1].append(seg)
+
+        i_obs = [obs] if not hasattr(obs, "__iter__") else obs
+        distance = zeros(segment.size, dtype=uint16) - 1
+
+        def loop(seg, dist=1):
+            i_slice, links = segments_connexion[seg]
+            d = distance[i_slice.start]
+
+            if dist < d and dist <= order:
+                distance[i_slice] = dist
+                for _seg in links:
+                    loop(_seg, dist + 1)
+
+        for indice in i_obs:
+            loop(segment[indice], 0)
+
+        return self.extract_with_mask(distance <= order)
+
+    # keep old names, for backward compatibility
+    relative = relatives
 
     def close_network(self, other, nb_obs_min=10, **kwargs):
         """
@@ -526,7 +559,7 @@ class NetworkObservations(GroupEddiesObservations):
         :param self other: Atlas to compare
         :param int nb_obs_min: Minimal number of overlap for one trajectory
         :param dict kwargs: keyword arguments for match function
-        :return: return other atlas reduce to common track with self
+        :return: return other atlas reduced to common tracks with self
 
         .. warning::
             It could be a costly operation for huge dataset
@@ -575,7 +608,7 @@ class NetworkObservations(GroupEddiesObservations):
         New numbering of segment
         """
         for i, _, _ in self.iter_on("track"):
-            new_numbering(self.segment[i])
+            new_numbering(self.segment[i], start)
 
     def numbering_network(self, start=1):
         """
@@ -629,7 +662,7 @@ class NetworkObservations(GroupEddiesObservations):
         **kwargs,
     ):
         """
-        Plot a timeline of a network.
+        Plot the timeline of a network.
         Must be called on only one network.
 
         :param matplotlib.axes.Axes ax: matplotlib axe used to draw
@@ -644,13 +677,7 @@ class NetworkObservations(GroupEddiesObservations):
         """
         self.only_one_network()
         j = 0
-        line_kw = dict(
-            ls="-",
-            marker="+",
-            markersize=6,
-            zorder=1,
-            lw=3,
-        )
+        line_kw = dict(ls="-", marker="+", markersize=6, zorder=1, lw=3,)
         line_kw.update(kwargs)
         mappables = dict(lines=list())
 
@@ -690,7 +717,7 @@ class NetworkObservations(GroupEddiesObservations):
         return mappables
 
     def event_timeline(self, ax, field=None, method=None, factor=1, colors_mode="roll"):
-        """mark events in plot"""
+        """Mark events in plot"""
         j = 0
         events = dict(spliting=[], merging=[])
 
@@ -804,11 +831,11 @@ class NetworkObservations(GroupEddiesObservations):
 
     def map_network(self, method, y, same=True, return_dict=False, **kw):
         """
-        transform data `y` with method `method` for each track.
+        Transform data `y` with method `method` for each track.
 
-        :param Callable method: method to apply on each  tracks
+        :param Callable method: method to apply on each track
         :param np.array y: data where to apply method
-        :param bool same: if True, return array same size from y. else, return list with track edited
+        :param bool same: if True, return an array with the same size than y. Else, return a list with the edited tracks
         :param bool return_dict: if None, mean values are used
         :param float kw: to multiply field
         :return: array or dict of result from method for each network
@@ -816,7 +843,7 @@ class NetworkObservations(GroupEddiesObservations):
 
         if same and return_dict:
             raise NotImplementedError(
-                "both condition 'same' and 'return_dict' should no be true"
+                "both conditions 'same' and 'return_dict' should no be true"
             )
 
         if same:
@@ -860,7 +887,7 @@ class NetworkObservations(GroupEddiesObservations):
         **kwargs,
     ):
         """
-        Must be call on only one network
+        Must be called on only one network
         """
         self.only_one_network()
         y = (self.segment if yfield is None else self.parse_varname(yfield)) * yfactor
@@ -880,13 +907,10 @@ class NetworkObservations(GroupEddiesObservations):
         return mappables
 
     def event_map(self, ax, **kwargs):
-        """Add the merging and splitting events """
+        """Add the merging and splitting events to a map"""
         j = 0
         mappables = dict()
-        symbol_kw = dict(
-            markersize=10,
-            color="k",
-        )
+        symbol_kw = dict(markersize=10, color="k",)
         symbol_kw.update(kwargs)
         symbol_kw_split = symbol_kw.copy()
         symbol_kw_split["markersize"] += 4
@@ -915,21 +939,15 @@ class NetworkObservations(GroupEddiesObservations):
         return mappables
 
     def scatter(
-        self,
-        ax,
-        name="time",
-        factor=1,
-        ref=None,
-        edgecolor_cycle=None,
-        **kwargs,
+        self, ax, name="time", factor=1, ref=None, edgecolor_cycle=None, **kwargs,
     ):
         """
-        This function will scatter the path of each network, with the merging and splitting events
+        This function scatters the path of each network, with the merging and splitting events
 
         :param matplotlib.axes.Axes ax: matplotlib axe used to draw
         :param str,array,None name:
-            variable used to fill the contour, if None all elements have the same color
-        :param float,None ref: if define use like west bound
+            variable used to fill the contours, if None all elements have the same color
+        :param float,None ref: if defined, ref is used as western boundary
         :param float factor: multiply value by
         :param list edgecolor_cycle: list of colors
         :param dict kwargs: look at :py:meth:`matplotlib.axes.Axes.scatter`
@@ -1087,7 +1105,7 @@ class NetworkObservations(GroupEddiesObservations):
 
     def dissociate_network(self):
         """
-        Dissociate network with no known interaction (spliting/merging)
+        Dissociate networks with no known interaction (spliting/merging)
         """
 
         tags = self.tag_segment(multi_network=True)
@@ -1101,7 +1119,7 @@ class NetworkObservations(GroupEddiesObservations):
         self.obs.sort(order=("track", "segment", "time"), kind="mergesort")
         self._index_network = None
 
-        # n & p must be re-index
+        # n & p must be re-indexed
         n, p = self.next_obs, self.previous_obs
         # we add 2 for -1 index return index -1
         nb_obs = len(self)
@@ -1124,17 +1142,17 @@ class NetworkObservations(GroupEddiesObservations):
         """
         Will set same temporary ID for each connected segment.
 
-        :param int seg: current ID of seg
-        :param ing tag: temporary ID to set for seg and its connexion
-        :param array[int] groups: array where tag will be stored
-        :param dict connexions: gives for one ID of seg all seg connected
+        :param int seg: current ID of segment
+        :param ing tag: temporary ID to set for segment and its connexion
+        :param array[int] groups: array where tag is stored
+        :param dict connexions: gives for one ID of segment all connected segments
         """
-        # If seg are already used we stop recursivity
+        # If segments are already used we stop recursivity
         if groups[seg] != 0:
             return
-        # We set tag for this seg
+        # We set tag for this segment
         groups[seg] = tag
-        # Get all connexions of this seg
+        # Get all connexions of this segment
         segs = connexions.get(seg, None)
         if segs is not None:
             for seg in segs:
@@ -1164,14 +1182,17 @@ class NetworkObservations(GroupEddiesObservations):
         return self.tag_segment().shape[0] == 1
 
     def remove_trash(self):
+        """
+        Remove the lonely eddies (only 1 obs in segment, associated segment number is 0)
+        """
         return self.extract_with_mask(self.track != 0)
 
     def plot(self, ax, ref=None, color_cycle=None, **kwargs):
         """
-        This function will draw path of each trajectory
+        This function draws the path of each trajectory
 
         :param matplotlib.axes.Axes ax: ax to draw
-        :param float,int ref: if defined, all coordinates will be wrapped with ref like west boundary
+        :param float,int ref: if defined, all coordinates are wrapped with ref as western boundary
         :param dict kwargs: keyword arguments for Axes.plot
         :return: a list of matplotlib mappables
         """
@@ -1198,15 +1219,15 @@ class NetworkObservations(GroupEddiesObservations):
 
     def remove_dead_end(self, nobs=3, ndays=0, recursive=0, mask=None):
         """
-        Remove short segment which didn't connect several segment
+        Remove short segments that don't connect several segments
 
-        :param int nobs: Minimal number of observation to keep segment
-        :param int ndays: Minimal number of days to keep segment
-        :param int recursive: Run  method N times more
-        :param int mask: if one or more observation of segment are select by mask, the segment is keep
+        :param int nobs: Minimal number of observation to keep a segment
+        :param int ndays: Minimal number of days to keep a segment
+        :param int recursive: Run method N times more
+        :param int mask: if one or more observation of the segment are selected by mask, the segment is kept
 
         .. warning::
-            It will remove short segment which splits than merges with same segment
+            It will remove short segment that splits from then merges with the same segment
         """
         segments_keep = list()
         connexions = self.connexions(multi_network=True)
@@ -1238,15 +1259,14 @@ class NetworkObservations(GroupEddiesObservations):
                 mask[i] = False
         return self.extract_with_mask(mask)
 
-    def extract_with_period(self, period):
+    def get_mask_with_period(self, period):
         """
-        Extract within a time period
+        obtain mask within a time period
 
-        :param (int,int) period: two dates to define the period, must be specify from 1/1/1950
-        :return: Return all eddy tracks which are in bounds
-        :rtype: NetworkObservations
+        :param (int,int) period: two dates to define the period, must be specified from 1/1/1950
+        :return: mask where period is defined
+        :rtype: np.array(bool)
 
-        .. minigallery:: py_eddy_tracker.NetworkObservations.extract_with_period
         """
         dataset_period = self.period
         p_min, p_max = period
@@ -1260,7 +1280,57 @@ class NetworkObservations(GroupEddiesObservations):
             mask *= self.time <= p_max
         elif p_max < 0:
             mask *= self.time <= (dataset_period[1] + p_max)
-        return self.extract_with_mask(mask)
+        return mask
+
+    def extract_with_period(self, period):
+        """
+        Extract within a time period
+
+        :param (int,int) period: two dates to define the period, must be specified from 1/1/1950
+        :return: Return all eddy trajectories in period
+        :rtype: NetworkObservations
+
+        .. minigallery:: py_eddy_tracker.NetworkObservations.extract_with_period
+        """
+
+        return self.extract_with_mask(self.get_mask_with_period(period))
+
+    def extract_light_with_mask(self, mask):
+        """extract data with mask, but only with variables used for coherence, aka self.array_variables
+
+        :param mask: mask used to extract
+        :type mask: np.array(bool)
+        :return: new EddiesObservation with data wanted
+        :rtype: self
+        """
+
+        if isinstance(mask, slice):
+            nb_obs = mask.stop - mask.start
+        else:
+            nb_obs = mask.sum()
+
+        # only time & contour_lon/lat_e/s
+        variables = ["time"] + self.array_variables
+        new = self.__class__(
+            size=nb_obs,
+            track_extra_variables=[],
+            track_array_variables=self.track_array_variables,
+            array_variables=self.array_variables,
+            only_variables=variables,
+            raw_data=self.raw_data,
+        )
+        new.sign_type = self.sign_type
+        if nb_obs == 0:
+            logger.warning("Empty dataset will be created")
+        else:
+            logger.info(
+                f"{nb_obs} observations will be extracted ({nb_obs / self.shape[0]:.3%})"
+            )
+
+        for field in variables:
+            logger.debug("Copy of field %s ...", field)
+            new.obs[field] = self.obs[field][mask]
+        return new
 
     def extract_with_mask(self, mask):
         """
@@ -1279,8 +1349,8 @@ class NetworkObservations(GroupEddiesObservations):
         if nb_obs == 0:
             logger.warning("Empty dataset will be created")
         else:
-            logger.info(
-                f"{nb_obs} observations will be extract ({nb_obs / self.shape[0]:.3%})"
+            logger.debug(
+                f"{nb_obs} observations will be extracted ({nb_obs / self.shape[0]:.3%})"
             )
             for field in self.obs.dtype.descr:
                 if field in ("next_obs", "previous_obs"):
@@ -1297,6 +1367,166 @@ class NetworkObservations(GroupEddiesObservations):
             new.previous_obs[:] = translate[p]
         return new
 
+    def analysis_coherence(
+        self,
+        date_function,
+        uv_params,
+        advection_mode="both",
+        dt_advect=14,
+        step_mesh=1.0 / 50,
+        output_name=None,
+        dissociate_network=False,
+        correct_close_events=0,
+        remove_dead_end=0,
+    ):
+
+        """Global function to analyse segments coherence, with network preprocessing"""
+
+        if dissociate_network:
+            self.dissociate_network()
+
+        if correct_close_events > 0:
+            self.correct_close_events(nb_days_max=correct_close_events)
+
+        if remove_dead_end > 0:
+            network_clean = self.remove_dead_end(nobs=0, ndays=remove_dead_end)
+        else:
+            network_clean = self
+
+        res = network_clean.segment_coherence(
+            date_function=date_function,
+            uv_params=uv_params,
+            advection_mode=advection_mode,
+            output_name=output_name,
+            dt_advect=dt_advect,
+            step_mesh=step_mesh,
+        )
+
+        return network_clean, res
+
+    def segment_coherence_backward(
+        self, date_function, uv_params, n_days=14, step_mesh=1.0 / 50, output_name=None,
+    ):
+
+        """
+        Percentage of particules and their targets after backward advection from a specific eddy.
+
+        :param callable date_function: python function, takes as param `int` (julian day) and return
+            data filename associated to the date (see note)
+        :param dict uv_params: dict of parameters used by
+            :py:meth:`~py_eddy_tracker.dataset.grid.GridCollection.from_netcdf_list`
+        :param int n_days: days for advection
+        :param float step_mesh: step for particule mesh in degrees
+        :return: observations matchs, and percents
+
+        .. note:: the param `date_function` should be something like :
+
+            .. code-block:: python
+
+                def date2file(julian_day):
+                    date = datetime.timedelta(days=julian_day) + datetime.datetime(
+                        1950, 1, 1
+                    )
+
+                    return f"/tmp/dt_global_{date.strftime('%Y%m%d')}.nc"
+        """
+
+        itb_final = -ones((self.obs.size, 2), dtype="i4")
+        ptb_final = zeros((self.obs.size, 2), dtype="i1")
+
+        t_start, t_end = self.period
+
+        dates = arange(t_start, t_start + n_days + 1)
+        first_files = [date_function(x) for x in dates]
+
+        c = GridCollection.from_netcdf_list(first_files, dates, **uv_params)
+        first = True
+        range_start = t_start + n_days
+        range_end = t_end + 1
+
+        for _t in range(t_start + n_days, t_end + 1):
+            _timestamp = time.time()
+            t_shift = _t
+
+            # skip first shift, because already included
+            if first:
+                first = False
+            else:
+                # add next date to GridCollection and delete last date
+                c.shift_files(t_shift, date_function(int(t_shift)), **uv_params)
+            particle_candidate(
+                c, self, step_mesh, _t, itb_final, ptb_final, n_days=-n_days
+            )
+            logger.info((
+                f"coherence {_t} / {range_end-1} ({(_t - range_start) / (range_end - range_start-1):.1%})"
+                f" : {time.time()-_timestamp:5.2f}s"
+            ))
+
+        return itb_final, ptb_final
+
+    def segment_coherence_forward(
+        self, date_function, uv_params, n_days=14, step_mesh=1.0 / 50,
+    ):
+
+        """
+        Percentage of particules and their targets after forward advection from a specific eddy.
+
+        :param callable date_function: python function, takes as param `int` (julian day) and return
+            data filename associated to the date (see note)
+        :param dict uv_params: dict of parameters used by
+            :py:meth:`~py_eddy_tracker.dataset.grid.GridCollection.from_netcdf_list`
+        :param int n_days: days for advection
+        :param float step_mesh: step for particule mesh in degrees
+        :return: observations matchs, and percents
+
+        .. note:: the param `date_function` should be something like :
+
+            .. code-block:: python
+
+                def date2file(julian_day):
+                    date = datetime.timedelta(days=julian_day) + datetime.datetime(
+                        1950, 1, 1
+                    )
+
+                    return f"/tmp/dt_global_{date.strftime('%Y%m%d')}.nc"
+        """
+
+        itf_final = -ones((self.obs.size, 2), dtype="i4")
+        ptf_final = zeros((self.obs.size, 2), dtype="i1")
+
+        t_start, t_end = self.period
+        # if begin is not None and begin > t_start:
+        #     t_start = begin
+        # if end is not None and end < t_end:
+        #     t_end = end
+
+        dates = arange(t_start, t_start + n_days + 1)
+        first_files = [date_function(x) for x in dates]
+
+        c = GridCollection.from_netcdf_list(first_files, dates, **uv_params)
+        first = True
+        range_start = t_start
+        range_end = t_end - n_days + 1
+
+        for _t in range(range_start, range_end):
+            _timestamp = time.time()
+            t_shift = _t + n_days
+
+            # skip first shift, because already included
+            if first:
+                first = False
+            else:
+                # add next date to GridCollection and delete last date
+                c.shift_files(t_shift, date_function(int(t_shift)), **uv_params)
+            particle_candidate(
+                c, self, step_mesh, _t, itf_final, ptf_final, n_days=n_days
+            )
+            logger.info((
+                f"coherence {_t} / {range_end-1} ({(_t - range_start) / (range_end - range_start-1):.1%})"
+                f" : {time.time()-_timestamp:5.2f}s"
+            ))
+        return itf_final, ptf_final
+
 
 class Network:
     __slots__ = (
@@ -1370,10 +1600,10 @@ class Network:
         Create a translator with all duos
 
         :param int nb: size of translator
-        :param set((int, int)) duos: set of all group which must be join
+        :param set((int, int)) duos: set of all groups that must be joined
+
+        :Example:
 
-        Examples
-        --------
         >>> NetworkObservations.group_translator(5, ((0, 1), (0, 2), (1, 3)))
         [3, 3, 3, 3, 5]
         """
@@ -1391,7 +1621,7 @@ class Network:
         for i, filename in enumerate(self.filenames):
             if display_iteration:
                 print(f"{filename} compared to {self.window} next", end="\r")
-            # Load observations with function to buffered observations
+            # Load observations with function to buffer observations
             xi, yi = self.buffer.load_contour(filename)
             # Append number of observations by filename
             nb_obs.append(xi.shape[0])
@@ -1416,7 +1646,7 @@ class Network:
         model = TrackEddiesObservations.load_file(self.filenames[-1], raw_data=raw_data)
         eddies = TrackEddiesObservations.new_like(model, nb_obs)
         eddies.sign_type = model.sign_type
-        # Get new index to re-order observation by group
+        # Get new index to re-order observations by groups
         new_i = get_next_index(group)
         display_iteration = logger.getEffectiveLevel() == logging.INFO
         elements = eddies.elements
@@ -1444,7 +1674,7 @@ class Network:
 
 @njit(cache=True)
 def get_next_index(gr):
-    """Return for each obs index the new position to join all group"""
+    """Return for each obs index the new position to join all groups"""
     nb_obs_gr = bincount(gr)
     i_gr = nb_obs_gr.cumsum() - nb_obs_gr
     new_index = empty(gr.shape, dtype=uint32)
