@@ -69,6 +69,7 @@ from ..poly import (
     poly_indexs,
     reduce_size,
     vertice_overlap,
+    winding_number_poly
 )
 
 logger = logging.getLogger("pet")
@@ -87,7 +88,7 @@ def shifted_ellipsoid_degrees_mask2(lon0, lat0, lon1, lat1, minor=1.5, major=1.5
     # Focal
     f_right = lon0
     f_left = f_right - (c - minor)
-    # Ellips center
+    # Ellipse center
     x_c = (f_left + f_right) * 0.5
 
     nb_0, nb_1 = lat0.shape[0], lat1.shape[0]
@@ -224,7 +225,7 @@ class EddiesObservations(object):
         return array_equal(self.obs, other.obs)
 
     def get_color(self, i):
-        """Return colors like a cyclic list"""
+        """Return colors as a cyclic list"""
         return self.COLORS[i % self.NB_COLORS]
 
     @property
@@ -260,7 +261,7 @@ class EddiesObservations(object):
         :param str,array varname: variable to use to compute stat
         :param str,array x: variable to use to know in which bins
         :param array bins:
-        :param bool percent: normalize by sum of all bins
+        :param bool percent: normalized by sum of all bins
         :param bool mean: compute mean by bins
         :param bool nb: only count by bins
         :return: value by bins
@@ -279,7 +280,7 @@ class EddiesObservations(object):
 
     @staticmethod
     def box_display(value):
-        """Return value evenly spaced with few numbers"""
+        """Return values evenly spaced with few numbers"""
         return "".join([f"{v_:10.2f}" for v_ in value])
 
     def field_table(self):
@@ -437,7 +438,7 @@ class EddiesObservations(object):
 
     def circle_contour(self, only_virtual=False, factor=1):
         """
-        Set contours as a circles from radius and center data.
+        Set contours as circles from radius and center data.
 
         .. minigallery:: py_eddy_tracker.EddiesObservations.circle_contour
         """
@@ -553,6 +554,8 @@ class EddiesObservations(object):
         :param str,array xname:
         :param array bins: bounds of each bin ,
         :return: index or mask, bound low, bound up
+
+        .. minigallery:: py_eddy_tracker.EddiesObservations.iter_on
         """
         x = self[xname] if isinstance(xname, str) else xname
         d = x[1:] - x[:-1]
@@ -570,7 +573,7 @@ class EddiesObservations(object):
             i = numba_digitize(x, bins) - 1
             # Order by bins
             i_sort = i.argsort()
-            # If in reduce mode we will translate i_sort in full array index
+            # If in reduced mode we will translate i_sort in full array index
             i_sort_ = translate[i_sort] if test else i_sort
             # Bound for each bins in sorting view
             i0, i1, _ = build_index(i[i_sort])
@@ -592,7 +595,9 @@ class EddiesObservations(object):
 
     def align_on(self, other, var_name="time", **kwargs):
         """
-        Align the time indexes of two datasets.
+        Align the time indices of two datasets.
+
+        .. minigallery:: py_eddy_tracker.EddiesObservations.align_on
         """
         iter_self = self.iter_on(var_name, **kwargs)
         iter_other = other.iter_on(var_name, **kwargs)
@@ -609,7 +614,7 @@ class EddiesObservations(object):
             yield indexs_self, indexs_other, b0_self, b1_self
 
     def insert_observations(self, other, index):
-        """Insert other obs in self at the index."""
+        """Insert other obs in self at the given index."""
         if not self.coherence(other):
             raise Exception("Observations with no coherence")
         insert_size = len(other.obs)
@@ -697,11 +702,7 @@ class EddiesObservations(object):
         .. code-block:: python
 
             kwargs_latlon_300 = dict(
-                include_vars=[
-                    "longitude",
-                    "latitude",
-                ],
-                indexs=dict(obs=slice(0, 300)),
+                include_vars=["longitude", "latitude",], indexs=dict(obs=slice(0, 300)),
             )
             small_dataset = TrackEddiesObservations.load_file(
                 filename, **kwargs_latlon_300
@@ -719,6 +720,7 @@ class EddiesObservations(object):
             zarr_file = filename_.endswith(end)
         else:
             zarr_file = False
+        logger.info(f"loading file '{filename}'")
         if zarr_file:
             return cls.load_from_zarr(filename, **kwargs)
         else:
@@ -738,10 +740,10 @@ class EddiesObservations(object):
         """Load data from zarr.
 
         :param str,store filename: path or store to load data
-        :param bool raw_data: If true load data without apply scale_factor and add_offset
-        :param None,list(str) remove_vars: List of variable name which will be not loaded
+        :param bool raw_data: If true load data without scale_factor and add_offset
+        :param None,list(str) remove_vars: List of variable name that will be not loaded
         :param None,list(str) include_vars: If defined only this variable will be loaded
-        :param None,dict indexs: Indexs to laad only a slice of data
+        :param None,dict indexs: Indexes to load only a slice of data
         :param int buffer_size: Size of buffer used to load zarr data
         :param class_kwargs: argument to set up observations class
         :return: Obsevations selected
@@ -760,7 +762,7 @@ class EddiesObservations(object):
         nb_obs = getattr(h_zarr, var_list[0]).shape[0]
         dims = list(cls.zarr_dimension(filename))
         if len(dims) == 2 and nb_obs in dims:
-            # FIXME must be investigate, in zarr no dimensions name (or could be add in attr)
+            # FIXME must be investigated, in zarr no dimensions name (or could be add in attr)
             array_dim = dims[1] if nb_obs == dims[0] else dims[0]
         if indexs is not None and "obs" in indexs:
             sl = indexs["obs"]
@@ -881,7 +883,7 @@ class EddiesObservations(object):
         :param bool raw_data: If true load data without apply scale_factor and add_offset
         :param None,list(str) remove_vars: List of variable name which will be not loaded
         :param None,list(str) include_vars: If defined only this variable will be loaded
-        :param None,dict indexs: Indexs to laad only a slice of data
+        :param None,dict indexs: Indexes to load only a slice of data
         :param class_kwargs: argument to set up observations class
         :return: Obsevations selected
         :return type: class
@@ -1050,7 +1052,7 @@ class EddiesObservations(object):
         self, previous_obs, current_obs, obs_to_extend, dead_track, nb_next, model
     ):
         """
-        Filled virtual obs (C).
+        Fill virtual obs (C).
 
         :param previous_obs: previous obs from current (A)
         :param current_obs: previous obs from virtual (B)
@@ -1131,7 +1133,7 @@ class EddiesObservations(object):
         :param bool intern: if True, speed contour is used (default = effective contour)
         :param float cmin: 0 < cmin < 1, return only couples with score >= cmin
         :param dict kwargs: look at :py:meth:`vertice_overlap`
-        :return: return the indexes of the eddies in self coupled with eddies in
+        :return: return the indices of the eddies in self coupled with eddies in
             other and their associated score
         :rtype: (array(int), array(int), array(float))
 
@@ -1162,7 +1164,7 @@ class EddiesObservations(object):
         :param array,int index: local index to re ref
         :param slice,array ref:
             reference could be a slice in this case we juste add start to index
-            or could be indexs and in this case we need to translate
+            or could be indices and in this case we need to translate
         """
         if isinstance(ref, slice):
             return index + ref.start
@@ -1244,7 +1246,7 @@ class EddiesObservations(object):
         )
 
     def fixed_ellipsoid_mask(
-        self, other, minor=50, major=100, only_east=False, shifted_ellips=False
+        self, other, minor=50, major=100, only_east=False, shifted_ellipse=False
     ):
         dist = self.distance(other).T
         accepted = dist < minor
@@ -1268,13 +1270,13 @@ class EddiesObservations(object):
             )
 
             lon_self = self.lon[index_self]
-            if shifted_ellips:
-                x_center_ellips = lon_self - (major - minor) / 2
+            if shifted_ellipse:
+                x_center_ellipse = lon_self - (major - minor) / 2
             else:
-                x_center_ellips = lon_self
+                x_center_ellipse = lon_self
 
-            lon_left_f = x_center_ellips - f_degree
-            lon_right_f = x_center_ellips + f_degree
+            lon_left_f = x_center_ellipse - f_degree
+            lon_right_f = x_center_ellipse + f_degree
 
             dist_left_f = distance(
                 lon_left_f,
@@ -1298,7 +1300,7 @@ class EddiesObservations(object):
         return accepted.T
 
     @staticmethod
-    def basic_formula_ellips_major_axis(
+    def basic_formula_ellipse_major_axis(
         lats, cmin=1.5, cmax=10.0, c0=1.5, lat1=13.5, lat2=5.0, degrees=False
     ):
         """Give major axis in km with a given latitude"""
@@ -1326,18 +1328,18 @@ class EddiesObservations(object):
     def solve_simultaneous(cost):
         """Write something (TODO)"""
         mask = ~cost.mask
-        # Count number of link by self obs and other obs
+        # Count number of links by self obs and other obs
         self_links, other_links = sum_row_column(mask)
         max_links = max(self_links.max(), other_links.max())
         if max_links > 5:
             logger.warning("One observation have %d links", max_links)
 
-        # If some obs have multiple link, we keep only one link by eddy
+        # If some obs have multiple links, we keep only one link by eddy
         eddies_separation = 1 < self_links
         eddies_merge = 1 < other_links
         test = eddies_separation.any() or eddies_merge.any()
         if test:
-            # We extract matrix which contains concflict
+            # We extract matrix that contains conflict
             obs_linking_to_self = mask[eddies_separation].any(axis=0)
             obs_linking_to_other = mask[:, eddies_merge].any(axis=1)
             i_self_keep = where(obs_linking_to_other + eddies_separation)[0]
@@ -1360,13 +1362,13 @@ class EddiesObservations(object):
             security_increment = 0
             while False in cost_reduce.mask:
                 if security_increment > max_iteration:
-                    # Maybe check if the size decrease if not rise an exception
+                    # Maybe check if the size decreases if not rise an exception
                     # x_i, y_i = where(-cost_reduce.mask)
                     raise Exception("To many iteration: %d" % security_increment)
                 security_increment += 1
                 i_min_value = cost_reduce.argmin()
                 i, j = floor(i_min_value / shape[1]).astype(int), i_min_value % shape[1]
-                # Set to False all link
+                # Set to False all links
                 mask[i_self_keep[i]] = False
                 mask[:, i_other_keep[j]] = False
                 cost_reduce.mask[i] = True
@@ -1380,19 +1382,19 @@ class EddiesObservations(object):
     @staticmethod
     def solve_first(cost, multiple_link=False):
         mask = ~cost.mask
-        # Count number of link by self obs and other obs
+        # Count number of links by self obs and other obs
         self_links = mask.sum(axis=1)
         other_links = mask.sum(axis=0)
         max_links = max(self_links.max(), other_links.max())
         if max_links > 5:
             logger.warning("One observation have %d links", max_links)
 
-        # If some obs have multiple link, we keep only one link by eddy
+        # If some obs have multiple links, we keep only one link by eddy
         eddies_separation = 1 < self_links
         eddies_merge = 1 < other_links
         test = eddies_separation.any() or eddies_merge.any()
         if test:
-            # We extract matrix which contains concflict
+            # We extract matrix that contains conflict
             obs_linking_to_self = mask[eddies_separation].any(axis=0)
             obs_linking_to_other = mask[:, eddies_merge].any(axis=1)
             i_self_keep = where(obs_linking_to_other + eddies_separation)[0]
@@ -1672,7 +1674,8 @@ class EddiesObservations(object):
             handler = zarr.open(filename, "w")
             self.to_zarr(handler, **kwargs)
         else:
-            with Dataset(filename, "w", format="NETCDF4") as handler:
+            nc_format = kwargs.pop("format", "NETCDF4")
+            with Dataset(filename, "w", format=nc_format) as handler:
                 self.to_netcdf(handler, **kwargs)
 
     @property
@@ -1696,7 +1699,7 @@ class EddiesObservations(object):
 
     def mask_from_polygons(self, polygons):
         """
-        Return mask for all observation in one of polygons list
+        Return mask for all observations in one of polygons list
 
         :param list((array,array)) polygons: list of x/y array which be used to identify observations
         """
@@ -1720,7 +1723,7 @@ class EddiesObservations(object):
 
         :param dict area: 4 coordinates in a dictionary to specify bounding box (lower left corner and upper right corner)
         :param dict kwargs: look at :py:meth:`extract_with_mask`
-        :return: Return all eddy tracks which are in bounds
+        :return: Return all eddy trajetories in bounds
         :rtype: EddiesObservations
 
         .. code-block:: python
@@ -1741,7 +1744,7 @@ class EddiesObservations(object):
         """
         Time sub sampling
 
-        :param int,float t0: reference time which will be keep
+        :param int,float t0: reference time that will be keep
         :param int,float time_step: keep every observation spaced by time_step
         """
         mask = (self.time - t0) % time_step == 0
@@ -1775,7 +1778,7 @@ class EddiesObservations(object):
         :param matplotlib.axes.Axes ax: matplotlib axe used to draw
         :param str,array,None name:
             variable used to fill the contour, if None all elements have the same color
-        :param float,None ref: if define use like west bound
+        :param float,None ref: if defined, all coordinates are wrapped with ref as western boundary
         :param float factor: multiply value by
         :param dict kwargs: look at :py:meth:`matplotlib.axes.Axes.scatter`
         :return: scatter mappable
@@ -1807,7 +1810,7 @@ class EddiesObservations(object):
         """
         :param matplotlib.axes.Axes ax: matplotlib axe used to draw
         :param str,array,None varname: variable used to fill the contours, or an array of same size than obs
-        :param float,None ref: if define use like west bound?
+        :param float,None ref: if defined, all coordinates are wrapped with ref as western boundary
         :param bool intern: if True draw speed contours instead of effective contours
         :param str cmap: matplotlib colormap name
         :param int,None lut: Number of colors in the colormap
@@ -1963,11 +1966,7 @@ class EddiesObservations(object):
 
     def format_label(self, label):
         t0, t1 = self.period
-        return label.format(
-            t0=t0,
-            t1=t1,
-            nb_obs=len(self),
-        )
+        return label.format(t0=t0, t1=t1, nb_obs=len(self),)
 
     def display(self, ax, ref=None, extern_only=False, intern_only=False, **kwargs):
         """Plot the speed and effective (dashed) contour of the eddies
@@ -2041,7 +2040,7 @@ class EddiesObservations(object):
 
     def contains(self, x, y, intern=False):
         """
-        Return index of contour which contain (x,y)
+        Return index of contour containing (x,y)
 
         :param array x: longitude
         :param array y: latitude
@@ -2050,7 +2049,12 @@ class EddiesObservations(object):
         :rtype: array[int32]
         """
         xname, yname = self.intern(intern)
-        return poly_indexs(x, y, self[xname], self[yname])
+        m = ~(isnan(x) + isnan(y))
+        i = -ones(x.shape, dtype="i4")
+
+        if x.size != 0 and m.any():
+            i[m] = poly_indexs(x[m], y[m], self[xname], self[yname])
+        return i
 
     def inside(self, x, y, intern=False):
         """
@@ -2220,6 +2224,8 @@ class EddiesObservations(object):
         :param str method: 'center', 'mean', 'max', 'min', 'nearest'
         :param str dtype: if None we use var dtype
         :param bool intern: Use extern or intern contour
+
+        .. minigallery:: py_eddy_tracker.EddiesObservations.interp_grid
         """
         if method in ("center", "nearest"):
             return grid_object.interp(varname, self.longitude, self.latitude, method)
@@ -2262,18 +2268,31 @@ class EddiesObservations(object):
 
     @property
     def nb_days(self):
-        """Return period days cover by dataset
+        """Return period in days covered by the dataset
 
         :return: Number of days
         :rtype: int
         """
         return self.period[1] - self.period[0] + 1
 
+    def create_particles(self, step, intern=True):
+        """create particles only inside speed contour. Avoid creating too large numpy arrays, only to me masked
+
+        :param step: step for particles
+        :type step: float
+        :param bool intern: If true use speed contour instead of effective contour
+        :return: lon, lat and indices of particles
+        :rtype: tuple(np.array)
+        """
+
+        xname, yname = self.intern(intern)
+        return _create_meshed_particles(self[xname], self[yname], step)
+
 
 @njit(cache=True)
 def grid_count_(grid, i, j):
     """
-    Add one to each index
+    Add 1 to each index
     """
     for i_, j_ in zip(i, j):
         grid[i_, j_] += 1
@@ -2296,7 +2315,7 @@ def grid_count_pixel_in(
     y_c,
 ):
     """
-    Count how many time a pixel is used.
+    Count how many times a pixel is used.
 
     :param array grid:
     :param array x: x for all contour
@@ -2319,14 +2338,7 @@ def grid_count_pixel_in(
         x_, y_ = reduce_size(x_, y_)
         v = create_vertice(x_, y_)
         (x_start, x_stop), (y_start, y_stop) = bbox_indice_regular(
-            v,
-            x_bounds,
-            y_bounds,
-            xstep,
-            ystep,
-            N,
-            is_circular,
-            x_size,
+            v, x_bounds, y_bounds, xstep, ystep, N, is_circular, x_size,
         )
         i, j = get_pixel_in_regular(v, x_c, y_c, x_start, x_stop, y_start, y_stop)
         grid_count_(grid, i, j)
@@ -2432,6 +2444,24 @@ def grid_stat(x_c, y_c, grid, x, y, result, circular=False, method="mean"):
             result[elt] = v_max
 
 
+@njit(cache=True)
+def _create_meshed_particles(lons, lats, step):
+    x_out, y_out, i_out = list(), list(), list()
+    for i, (lon, lat) in enumerate(zip(lons, lats)):
+        lon_min, lon_max = lon.min(), lon.max()
+        lat_min, lat_max = lat.min(), lat.max()
+        lon_min -= lon_min % step
+        lon_max -= lon_max % step - step * 2
+        lat_min -= lat_min % step
+        lat_max -= lat_max % step - step * 2
+
+        for x in arange(lon_min, lon_max, step):
+            for y in arange(lat_min, lat_max, step):
+                if winding_number_poly(x, y, create_vertice(*reduce_size(lon, lat))):
+                    x_out.append(x), y_out.append(y), i_out.append(i)
+    return array(x_out), array(y_out), array(i_out)
+
+
 class VirtualEddiesObservations(EddiesObservations):
     """Class to work with virtual obs"""
 
